==> slackbot_jucho-0.1.5-py3-none-any.whl: slackbot/post.py <==
import slackbot
import json
import requests
from datetime import datetime

def post_message(message):
    webhook_url = "https://hooks.slack.com/services/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"

    data = [{"type": "section",
         "text": {
              "type": "mrkdwn",
              "text": f"{message}"
          }}]
    slack_data = json.dumps({'text': 'message from noti_bot',
        'blocks': data})
    response = requests.post(webhook_url,
                             data=slack_data,
                             headers={'Content-type': 'application/json'}
    )
    if response.status_code != 200:
        raise ValueError(
        f'Request to slackbot returned an error {response.status_code}\n \
        the response is {response.text}')


def post_job_done(work_name):
    webhook_url = "https://hooks.slack.com/services/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"

    data = [{"type": "section",
#             "user": "U01SH0HL4PR",
             "text": {
                 "type": "mrkdwn",
                 "text": f"<@U01SH0HL4PR|cal>, the work {work_name} done at {datetime.now().strftime(r'%m%d_%H%M')}"
             }}]
    slack_data = json.dumps({'text': f"{work_name} job-done!!!!! \n {work_name} job-done!!!!! \n {work_name} job-done!!!!! \n {work_name} job-done!!!!! \n {work_name} job-done!!!!! \n {work_name} job-done!!!!! \n {work_name} job-done!!!!! \n {work_name} job-done!!!!! \n",
        'blocks': data})
    response = requests.post(webhook_url,
                             data=slack_data,
                             headers={'Content-type': 'application/json'}
                             )
    if response.status_code != 200:
        raise ValueError(
            f'Request to slackbot returned an error {response.status_code}\n \
        the response is {response.text}')

if __name__ == "__main__":
    post_message("test")
    post_job_done("test")

==> slackbot_jucho-0.2.1-py3-none-any.whl: slackbot/post.py <==
import slackbot
import json
import requests
from datetime import datetime

def post_message(message):
    webhook_url = "https://hooks.slack.com/services/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"

    data = [{"type": "section",
         "text": {
              "type": "mrkdwn",
              "text": f"<@U01SH0HL4PR|cal>, {message}"
          }}]
    slack_data = json.dumps({'text': 'message from noti_bot',
        'blocks': data})
    response = requests.post(webhook_url,
                             data=slack_data,
                             headers={'Content-type': 'application/json'}
    )
    if response.status_code != 200:
        raise ValueError(
        f'Request to slackbot returned an error {response.status_code}\n \
        the response is {response.text}')


def post_job_done(work_name):
    webhook_url = "https://hooks.slack.com/services/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"

    data = [{"type": "section",
#             "user": "U01SH0HL4PR",
             "text": {
                 "type": "mrkdwn",
                 "text": f"<@U01SH0HL4PR|cal>, the work {work_name} done at {datetime.now().strftime(r'%m%d_%H%M')}"
             }}]
    slack_data = json.dumps({'text': f"[COMPLETED] {work_name} has been completed :)",
        'blocks': data})
    response = requests.post(webhook_url,
                             data=slack_data,
                             headers={'Content-type': 'application/json'}
                             )
    if response.status_code != 200:
        raise ValueError(
            f'Request to slackbot returned an error {response.status_code}\n \
        the response is {response.text}')

if __name__ == "__main__":
    # post_message("test")
    post_job_done("test")
